Package 'victortools'

Title: Mainipulate the Output File from the Victor
Description: This package will parse the output from the Victor, clean data, summarize data, and perform some basic stats functions that may be relevant for data analysis.
Authors: Shaurita Hutchins [aut, cre]
Maintainer: Shaurita Hutchins <[email protected]>
License: MIT + file LICENSE
Version: 0.1
Built: 2026-06-09 19:15:42 UTC
Source: https://github.com/sdhutchins/victortools

Help Index


Add Metadata

Description

Adds additional metadata to the metadata list

Usage

add_metadata(metadata, title, data)

Arguments

metadata

The input metadata list

title

The title or descriptor of the metadata

data

The output file from the Victor run

Value

An updated list of metadata is returned


AP1 Expression Test columns

Description

Use these columns when testing AP1 expression.

Control

control well

10 ng/ul PMA

experiemental well

Usage

ap1_cols

Format

An object of class character of length 2.


CRE Expression Test columns

Description

Use these columns when testing CRE expression.

Control

control well

10 uM Forskolin

experiemental well

Usage

cre_cols

Format

An object of class character of length 2.


Expression Barplot

Description

A barplot of expression data.

Usage

expression_barplot(assay_data)

Arguments

assay_data

The assay data frame.


Get Assay Data

Description

Retrieves and cleans assay results from Victor ouput file

Usage

get_assay_data(file)

Arguments

file

The output file from the Victor run

Value

A dataframe of the assay results is returned


Get Metadata

Description

Retrieves metadata from Victor ouput file

Usage

get_metadata(file)

Arguments

file

The output file from the Victor run

Value

A list of metadata is returned


Import Victor File

Description

Imports and manipulates the victor file

Usage

import_victor_file(filename)

Arguments

filename

The output file from the Victor run

Value

Returns a list of assay and metadata from a Victor file


NFkB Expression Test columns

Description

Use these columns when testing NFkB expression.

Control

control well

10 ng/ul TNFa

experiemental well

Usage

nfkb_cols

Format

An object of class character of length 2.


Select Data

Description

Selects columns and rows from assay data to analyze

Usage

select_data(data, columns, rows)

Arguments

data

The assay data object.

columns

The rows to select.

rows

The rows to select.

Value

Returns a subsetted data object.


SRE Expression Test columns

Description

SRE Expression Test columns

Usage

sre_cols

Format

An object of class character of length 4.