| Title: | Mainipulate the Output File from the Victor |
|---|---|
| Description: | This package will parse the output from the Victor, clean data, summarize data, and perform some basic stats functions that may be relevant for data analysis. |
| Authors: | Shaurita Hutchins [aut, cre] |
| Maintainer: | Shaurita Hutchins <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1 |
| Built: | 2026-06-09 19:15:42 UTC |
| Source: | https://github.com/sdhutchins/victortools |
Adds additional metadata to the metadata list
add_metadata(metadata, title, data)add_metadata(metadata, title, data)
metadata |
The input metadata list |
title |
The title or descriptor of the metadata |
data |
The output file from the Victor run |
An updated list of metadata is returned
Use these columns when testing AP1 expression.
control well
experiemental well
ap1_colsap1_cols
An object of class character of length 2.
Use these columns when testing CRE expression.
control well
experiemental well
cre_colscre_cols
An object of class character of length 2.
A barplot of expression data.
expression_barplot(assay_data)expression_barplot(assay_data)
assay_data |
The assay data frame. |
Retrieves and cleans assay results from Victor ouput file
get_assay_data(file)get_assay_data(file)
file |
The output file from the Victor run |
A dataframe of the assay results is returned
Retrieves metadata from Victor ouput file
get_metadata(file)get_metadata(file)
file |
The output file from the Victor run |
A list of metadata is returned
Imports and manipulates the victor file
import_victor_file(filename)import_victor_file(filename)
filename |
The output file from the Victor run |
Returns a list of assay and metadata from a Victor file
Use these columns when testing NFkB expression.
control well
experiemental well
nfkb_colsnfkb_cols
An object of class character of length 2.
Selects columns and rows from assay data to analyze
select_data(data, columns, rows)select_data(data, columns, rows)
data |
The assay data object. |
columns |
The rows to select. |
rows |
The rows to select. |
Returns a subsetted data object.
SRE Expression Test columns
sre_colssre_cols
An object of class character of length 4.